%EstimateRisk_HRS.m

function EstimateRisk_PSID(c92,c94,c98,c00,c02,X92,X94,X98,X00,X02);
global cpt6 cpt4 model 

% Updated October 23, 2008
% Claudia Sahm
 
N = size(c92,1);
maxit = 200;
tol = 1.0e-6; 

%% Compute Risk Tolerance Cutoffs for Risk Categories;
dfrac = 1 - [1/10,1/5,1/3,1/2,3/4]; %(1 - downside risk) 
cutoff = zeros(1,size(dfrac,2));
for j = 1:size(dfrac,2)
    gamma = 5; % Initial guess for coefficient of relative risk aversion;
    for it=1:maxit  % Newton Rootfinder;  
        [fval,fjac] = dutility(gamma,dfrac(1,j));
        gamma = gamma - fjac\fval; 
        if norm(fval) < tol, break, end 
    end
    cutoff(1,j) = gamma.^-1; % Risk tolerance (Inverse of Risk Aversion);
end

%% Assign cutoff ranges
cpt6 = [-1.0e+77;log(cutoff)';1.0e+77]; % 6-way categories
cpt4 = [-1.0e+77;log(cutoff(2:end-1))';1.0e+77]; % 4-way categories 

tic;

% Initial parameter guess;
if model == 1 % Common Mean, Common Variance
        b = zeros(2,1);
        b(1,1) = -1.97; % Constant
        b(2,1) =  1.50; % Std. dev. e 

elseif model == 2 % Age-Adjusted Mean and Variance
        b = zeros(6,1);
	b(1,1) = -1.00; % Age 40-49
	b(2,1) = -1.00; % Age 50-59
	b(3,1) = -1.00; % Age 60-69
	b(4,1) = 1.50; % SD e: Age 40-49
	b(5,1) = 1.50; % SD e: 50-59
	b(6,1) = 1.50; % SD e: 60-69
       
elseif model == 10 % Common Mean, Common Variance
        b = zeros(3,1);
        b(1,1) = -1.97; % Mean
	b(2,1) =  0.70; % Std. dev. u 
        b(3,1) =  1.50; % Std. dev. e          

elseif model == 11 % Common Mean, SQB, Common Variance
        b = zeros(4,1);
        b(1,1) = -1.97; % Mean
        b(2,1) = -0.11; % SQB
	b(3,1) =  0.70; % Std. dev. u 
        b(4,1) =  1.50; % Std. dev. e        

end

 info.cnames = strvcat('estimate','t-stat','step');
    info.fmt=strvcat('%15.3f','%15.3f','%15.6f');
    
        if model == 1   
          	info.rnames = strvcat(' ','Mean','Std. dev. e'); 
        elseif model == 2
   	       info.rnames = strvcat(' ','Mn: Age 40-49',...
		'Mn: Age 50-59','Mn: 60-69',...
 		'Sd e: Age 40-49','Sd e: Age 50-59','Sd e: 60-69');     
        elseif model == 10   
          	info.rnames = strvcat(' ','Mean','Std. dev. u','Std. dev. e');  
        elseif model == 11   
          	info.rnames = strvcat(' ','Mean','SQB','Std. dev. u','Std. dev. e');  
	end

    iter = 0;
    err = 1;
    
    % Find parameter values which maximize the
    % log-likelihood of the responses
    
    maxit = 30;
    lik = zeros(N,1);
    si = zeros(N,size(b,1));
    si = sparse(si);
    while (iter < maxit) & err >= tol 
        lik = like_HRS(b,c92,c94,c98,c00,c02,X92,X94,X98,X00,X02);
        si = fdjac('like_HRS',b,c92,c94,c98,c00,c02,X92,X94,X98,X00,X02);

        L = sum(lik);
        d = inv(si'*si)*si'*ones(N,1);
        b = b + d;
        
        err = abs(max(max(d)));
        
        iter = iter + 1;
        sumsi = sum(si);    
        V = inv(si'*si);
        se = diag(V).^.5;
        err=full(err);
        disp(sprintf('Error at iteration %1.0f = %1.2e', iter,err ));
       
        itertime = clock;
        disp(DATESTR(itertime,0));
        mprint([b,b./se,d],info)
        disp(sprintf('Log-likelihood %10.1f', L));
      
        save results_im b iter se err sumsi d lik si L  N model itertime ;
    end    


    L = sum(lik);
    
    %% Standard errors of estimates
    V = inv(si'*si);
    se = diag(V).^.5;
        
    if model == 0 
        save results_00 b V se L iter err N itertime sumsi model;      
    elseif model == 1 
        save results_01 b V se L iter err N itertime sumsi model;       
    elseif model == 2 
        save results_02 b V se L iter err N itertime sumsi model;  
    elseif model == 10 
        save results_10 b V se L iter err N itertime sumsi model; 
    elseif model == 11 
        save results_11 b V se L iter err N itertime sumsi model; 
    end
    
    disp(sprintf('Estimates of Model %1.0f', model ));
    disp(DATESTR(itertime,0))
    disp(sprintf('Sample size %1.0f', N ));
    disp(sprintf('Number of iterations = %1.0f', iter ));
    err=full(err);
    disp(sprintf('Error at last iteration = %1.2e', err )); 
        
    info.cnames = strvcat('estimate', 'std. error','t-stat');
    info.fmt='%15.3f';
    
    mprint([b,se,b./se],info)
    disp(sprintf('Log-likelihood %10.1f', L ));



