%EstimateRisk_PSID.m

function EstimateRisk_PSID(c,cR,X,XR);
global cpt6 model 

% Updated Nov 5, 2008
% Claudia Sahm
 
N = size(c,1);
maxit = 200;
tol = 1.0e-6; 

%% Compute Risk Tolerance Cutoffs for Risk Categories;
dfrac = 1 - [1/10,1/5,1/3,1/2,3/4]; %(1 - downside risk) 
cutoff = zeros(1,size(dfrac,2));
for j = 1:size(dfrac,2)
    gamma = 5; % Initial guess for coefficient of relative risk aversion;
    for it=1:maxit  % Newton Rootfinder;  
        [fval,fjac] = dutility(gamma,dfrac(1,j));
        gamma = gamma - fjac\fval; 
        if norm(fval) < tol, break, end 
    end
    cutoff(1,j) = gamma.^-1; % Risk tolerance (Inverse of Risk Aversion);
end

%% Assign cutoff ranges
cpt6 = [-1.0e+77;log(cutoff)';1.0e+77]; % 6 categories
tic;

% Initial parameter guess;

if model == 1 % Common Mean, Common Variance
        b = zeros(2,1);
        b(1,1) = -1.97; % Constant
        b(2,1) =  1.50; % Std. dev. e 

elseif model == 2 % Age-Adjusted Mean and Variance
        b = zeros(10,1);
	b(1,1) = -1.7; % Age 20-29
	b(2,1) = -1.7; % Age 30-39
	b(3,1) = -1.7; % Age 40-49
	b(4,1) = -1.7; % Age 50-59
	b(5,1) = -1.7; % Age 60-69
        b(6,1) = 1.50; % SD e: Age 20-29
        b(7,1) = 1.50; % SD e: Age 30-39
        b(8,1) = 1.50; % SD e: Age 40-49
	b(9,1) = 1.50; % SD e: Age 50-59
	b(10,1) = 1.50; % SD e: Age 60-69

elseif model == 10 % Age-Adjusted Mean and Variance
        b = zeros(5,1);
	b(1,1) = -1.0; % Mn: 1st in Pair
	b(2,1) = -1.0; % Mn: 2nd in Pair
	b(3,1) = .20; % Std. Dev. Family Effect
	b(4,1) = 1.5; % Std e: 1st in Pair
	b(5,1) = 1.5; % Std e: 2nd in Pair

end

 info.cnames = strvcat('estimate','t-stat','step');
    info.fmt=strvcat('%15.3f','%15.3f','%15.6f');
    
        if model == 1   
          	info.rnames = strvcat(' ','Mean','Std. dev. e'); 

        elseif model == 2
        	info.rnames = strvcat(' ','Mn: Age 20-29',...
		'Mn: Age 30-39','Mn: Age 40-49',...
		'Mn: Age 50-59','Mn: 60-69',...
		'Sd: Age 20-29','Sd: Age 30-39',...
		'Sd: Age 40-49','Sd: Age 50-59','Sd: 60-69');
  
        elseif model == 10
        	info.rnames = strvcat(' ','Mn: 1st in Pair','Mn: 2nd in Pair','Sd: Family Effect', ...
		'Sd e: 1st in Pair', 'Sd e: 2nd in Pair'); 

	end

    iter = 0;
    err = 1;
    
    % Find parameter values which maximize the
    % log-likelihood of the responses
    
    maxit = 30;
    lik = zeros(N,1);
    si = zeros(N,size(b,1));
    si = sparse(si);
    while (iter < maxit) & err >= tol 
        lik = like(b,c,cR,X,XR);
        si = fdjac('like',b,c,cR,X,XR);

        L = sum(lik);
        d = inv(si'*si)*si'*ones(N,1);
        b = b + d;
        
        err = abs(max(max(d)));
        
        iter = iter + 1;
        sumsi = sum(si);    
        V = inv(si'*si);
        se = diag(V).^.5;
        err=full(err);
        disp(sprintf('Error at iteration %1.0f = %1.2e', iter,err ));
       
        itertime = clock;
        disp(DATESTR(itertime,0));
        mprint([b,b./se,d],info)
        disp(sprintf('Log-likelihood %10.1f', L));
      
        save results_im b iter se err sumsi d lik si L  N model itertime ;
    end    


    L = sum(lik);
    
    %% Standard errors of estimates
    V = inv(si'*si);
    se = diag(V).^.5;
        
    if model == 0 
        save results_00 b V se L iter err N itertime sumsi model;      
    elseif model == 1 
        save results_01 b V se L iter err N itertime sumsi model;       
    elseif model == 2 
        save results_02 b V se L iter err N itertime sumsi model;  
    elseif model == 10 
        save results_10 b V se L iter err N itertime sumsi model; 
    end
    
    disp(sprintf('Estimates of Model %1.0f', model ));
    disp(DATESTR(itertime,0))
    disp(sprintf('Sample size %1.0f', N ));
    disp(sprintf('Number of iterations = %1.0f', iter ));
    err=full(err);
    disp(sprintf('Error at last iteration = %1.2e', err )); 
        
    info.cnames = strvcat('estimate', 'std. error','t-stat');
    info.fmt='%15.3f';
    
    mprint([b,se,b./se],info)
    disp(sprintf('Log-likelihood %10.1f', L ));



