
function [Etheta] = Etheta_KSS(b,c,X);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Etheta.m
% Computes the E(theta|c,X)
% Claudia R. Sahm (claudia.r.sahm@frb.gov)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global model  

maxit = 200;
tol = 1.0e-6; 

%% Compute Risk Tolerance Cutoffs for Risk Categories;
dfrac = 1 - [1/10,1/5,1/3,1/2,3/4]; %(1 - downside risk) 
cutoff = zeros(1,size(dfrac,2));
for j = 1:size(dfrac,2)
    gamma = 5; % Initial guess for coefficient of relative risk aversion;
    for it=1:maxit  % Newton Rootfinder;  
        [fval,fjac] = dutility(gamma,dfrac(1,j));
        gamma = gamma - fjac\fval; 
        if norm(fval) < tol, break, end 
    end
    cutoff(1,j) = gamma.^-1; % Risk tolerance (Inverse of Risk Aversion);
end

%% Assign cutoff ranges
cpt6 = [-1.0e+77;log(cutoff)';1.0e+77]; % 6 categories
tic;

Nodes = 20; % Nodes for Guassian quadrature
N = size(X,1);
K = size(X,2);
B = size(b,1);

% Likelihood of individual being in risk categories
muX = X*b(1:K,1); % mean of log risk tolerance - own

sigmau = b(2,1);
sigma = repmat((b(2,1)^2 + b(3,1)^2)^.5, N,1);

num = ones(N,1);
den = ones(N,1);

i = find(c>0); 
   num(i,1) = norm_cdf((cpt6(c(i)+1)-muX(i)-sigmau^2)./sigma(i)) - ...
       norm_cdf((cpt6(c(i))-muX(i)-sigmau^2)./sigma(i));
   den(i,1) = norm_cdf((cpt6(c(i)+1)-muX(i))./sigma(i))-norm_cdf((cpt6(c(i))-muX(i))./sigma(i));

%% Proxy
Etheta = exp(muX+sigmau^2/2).*(num./den);

