************************************
* HRS_Compare.sas
*
* Description: Creates a data set of
* gamble responses in the HRS that is
* comparable to sample in PSID
* 
* Sample: answer gamble in 1992 
* and working at the time of gamble responses
* and between ages 40 and 69 in 1992
*
* Programmed: Claudia Sahm
* Updated: February 10, 2009
************************************;

%let home = G:\res\Data\HRS\;

libname hrs1992 "&home.1992";
libname hrs1994 "&home.1994";
libname hrs1998 "&home.1998";
libname hrs2000 "&home.2000";
libname hrs2002 "&home.2002";

libname tracker "&home.tracker";
libname final 'G:\res\Research\RiskPrefs\InterGenPrefs_KSS\Analysis';

libname rand "G:\res\Data\HRS\Rand";
%let fmtlib=G:\res\Data\HRS\Rand\Fmt;  
libname library "&fmtlib";

%let maclib=G:\res\Data\HRS\Rand\Mac\; 
%include "&maclib.wvlist.mac";
%include "&maclib.wvlabel.mac";
%include "&maclib.addsp2.mac";
%let maxwv = 6;

%macro gtabs(var,yr);
proc freq data = risk&yr; 
tables &var._&yr / missing;
%mend;

**********************;
** HRS 1992         **;
** JOB GAMBLE       **;
**********************;

data risk1992(keep=hhid pn jrc4_1992 no_sp_prt_1992);
	set hrs1992.HEALTH;

if v7103 = 5 then no_sp_prt_1992 = 1;
	else if v7103 in(1,2,3) then no_sp_prt_1992 = 0;
	else no_sp_prt_1992 = 9;

if v5122=5 and v5123=5 then jrc4_1992 = 1;
	else if v5122=5 and v5123=1 then jrc4_1992 = 2;
	else if v5122=1 and v5123=5 then jrc4_1992 = 3;
	else if v5122=1 and v5123=1 then jrc4_1992 = 4;
	else if v5122 in(8,9) or v5123 in(8,9) then jrc4_1992 = .D;
	else jrc4_1992 = .;

%gtabs(jrc4,1992);
proc freq; tables no_sp_prt_1992; run;


**********************;
** HRS 1994 MODULE  **;
** JOB GAMBLE       **;
**********************;

data risk1994(keep=hhid pn jrc6_1994);
	set hrs1994.W2MOD5(keep=hhid pn W9344-W9348); 

if W9344=5 and W9346 = 5 and W9347 = 5 then jrc6_1994=1;
	else if W9344=5 and W9346 = 5 and W9347 = 1 then jrc6_1994=2;
	else if W9344=5 and W9346 = 1 then jrc6_1994=3;
	else if W9344=1 and W9345 = 5 then jrc6_1994=4;
	else if W9344=1 and W9345 = 1 and W9348 = 5 then jrc6_1994=5;
	else if W9344=1 and W9345 = 1 and W9348 = 1 then jrc6_1994=6;
	else if W9344 in(8,9) or W9345 in(8,9) or 
		W9346 in(8,9) or W9347 in(8,9) or W9348 in(8,9) then jrc6_1994=.D;
	else jrc6_1994 = .;

%gtabs(jrc6,1994); 

** Anyone present at interview?;
data iw94(keep = hhid pn no_sp_prt_1994);
	set hrs1994.W2CS(keep = hhid pn W135);

if W135 in(1,3) then no_sp_prt_1994 = 1;
	else if W135 in(2,0) then no_sp_prt_1994 = 0;
	else no_sp_prt_1994 = 9;
proc freq; tables no_sp_prt_1994; run;

proc sort data = risk1994; by hhid pn;
proc sort data = iw94; by hhid pn;

data risk1994;
	merge risk1994(in=inRK); 
	by hhid pn;
if inRK;

**********************;
** HRS 1998         **;
** JOB GAMBLE       **;
**********************;

data risk1998(keep=hhid pn jrc6_1998);
	set hrs1998.H98H_R(keep=hhid pn F4614-F4618);

if  F4614=1 and  F4617 = 1 and  F4618 = 1 then jrc6_1998=1; /*H18-H18D*/
	else if F4614=1 and F4617 = 1 and F4618 = 2 then jrc6_1998=2;
	else if F4614=1 and F4617 = 2 then jrc6_1998=3;
	else if F4614=2 and F4615 = 1 then jrc6_1998=4;
	else if F4614=2 and F4615 = 2 and F4616 = 1 then jrc6_1998=5;
	else if F4614=2 and F4615 = 2 and F4616 = 2 then jrc6_1998=6;
	else if F4614 in(8,9) or F4615 in(8,9) or 
		F4616 in(8,9) or F4617 in(8,9) or F4618 in(8,9) then jrc6_1998=.D;
	else risk6_1998 = .;

%gtabs(jrc6,1998);

**********************;
** HRS 2000         **;
** JOB GAMBLE       **;
**********************;

proc sort data = hrs2000.H00H_R out = H00H_R; by hhid pn;

data risk2000(keep=hhid pn jrc6_2000);
	merge H00H_R(keep=hhid pn G5027 G5033-G5036);
	by hhid pn;

if  G5027=1 and G5035 = 1 and  G5036 = 1 then jrc6_2000=1; 
	else if G5027=1 and G5035 = 1 and G5036 = 2 then jrc6_2000=2;
	else if G5027=1 and G5035 = 2 then jrc6_2000=3;
	else if G5027=2 and G5033 = 1 then jrc6_2000=4;
	else if G5027=2 and G5033 = 2 and G5034 = 1 then jrc6_2000=5;
	else if G5027=2 and G5033 = 2 and G5034 = 2 then jrc6_2000=6;
	else if G5027 in(8,9) or G5033 in(8,9) or 
		G5034 in(8,9) or G5035 in(8,9) or G5036 in(8,9) then jrc6_2000=.D;
	else jrc6_2000 = .;

%gtabs(jrc6,2000); 

proc freq data = risk2000;
	tables jrc6_2000*src4_2000;

**********************;
** HRS 2002         **;
** JOB GAMBLE       **;
**********************;

proc sort data = hrs2002.H02P_R out = H02P_R; by hhid pn;
proc sort data = hrs2002.H02V_R out = H02V_R; by hhid pn;

data risk2002(keep=hhid pn jrc6_2002);
	merge H02P_R(keep=hhid pn HP036-HP040 HP060-HP064 HP065-HP069);
	by hhid pn;

if  HP036=1 and HP039 = 1 and  HP040 = 1 then jrc6_2002=1; 
	else if HP036=1 and HP039 = 1 and HP040 = 2 then jrc6_2002=2;
	else if HP036=1 and HP039 = 2 then jrc6_2002=3;
	else if HP036=2 and HP037 = 1 then jrc6_2002=4;
	else if HP036=2 and HP037 = 2 and HP038 = 1 then jrc6_2002=5;
	else if HP036=2 and HP037 = 2 and HP038 = 2 then jrc6_2002=6;
	else if HP036 in(8,9) or HP037 in(8,9) or 
		HP038 in(8,9) or HP039 in(8,9) or HP040 in(8,9) then jrc6_2002=.D;
	else jrc6_2002 = .;

%gtabs(jrc6,2002);

** Anyone present at interview?;
data iw02(keep = hhid pn no_sp_prt_2002);
	set hrs2002.h02io_R(keep = hhid pn H055);

if H055 = 5 then no_sp_prt_2002 = 1;
	else no_sp_prt_2002 = 0;

proc sort data = risk2002; by hhid pn;
proc sort data = iw02; by hhid pn;

data risk2002;
	merge risk2002(in=inRK) iw02; 
	by hhid pn;
if inRK;


*** Merge Gamble Waves using Tracker File ***;
data tracker;
	set tracker.trk2006(keep=hhid pn ovresult ovhhid ovpn
	gender birthyr birthmo schlyrs race
	afinr cfinr efinr ffinr gfinr hfinr);

if gender = 1 then male = 1;
	else if gender = 2 then male = 0;
drop gender;

if race = 2 then black = 1;
	else black = 0;
drop race;

*** Deal with 1992 overlap ids;
data tracker92(keep=hhid pn hhidtrk pntrk);
	set tracker;
hhidtrk = hhid;
pntrk = pn;

if ovresult=1 then do;
	hhid=ovhhid;
	pn=ovpn;
end;

proc sort data = risk1992; by hhid pn;
proc sort data = tracker92; by hhid pn;

data risk1992;
	merge risk1992(in=in92) tracker92;
	by hhid pn;
if in92;

** Set to new id's;
hhid = hhidtrk;
pn = pntrk; 

proc sort data = risk1992; by hhid pn;
proc sort data = risk1994; by hhid pn;

data hrs9202(drop = hhidtrk pntrk OVRESULT);
	merge tracker(in=inTR) risk1992 risk1994 risk1998 risk2000 risk2002 iw94;
	by hhid pn;
	if (inTR=1);

hhidpn = hhid*1000 + pn;
if 1 <= jrc4_1992 <= 4 or 1 <= jrc6_1994 <= 6 or 1 <= jrc6_1998 <= 6 
	or 1 <= jrc6_2000 <= 6 or 1 <= jrc6_2002 <= 6;

run;

** Work related variables;
%macro workstat(n,yr);
** Currently working for pay;
if R&n.WORK = 1 then work_&yr = 1;
	else work_&yr = 0;
%mend;

** Married/Partnered;
%macro marstat(n,yr);
** Married = 1, Married, spouse absent = 2, Partnered = 3;
if R&n.MSTAT in(1,2,3) then married_&yr = 1;
	else married_&yr = 0;

if 0 <= R&n.MCURLN < 100 then yrmarried_&yr = R&n.MCURLN;

shhidpn_&yr = S&n.HHIDPN;
%mend;

** Income/Wealth;
%macro wealth(n,yr);
* Income over previous year;
%let yrL = %eval(&yr-1);
if H&n.ITOT ne . then totinc_&yr = H&n.ITOT * pindex(1995)/pindex(&yrL);

if totinc_&yr > 0 then lninc_&yr = log(totinc_&yr);
 	else if totinc_&yr ne . then lninc_&yr = 0;
%mend;

data rand(keep = hhidpn 
	shhidpn_1992 shhidpn_1994 shhidpn_1996 shhidpn_1998 shhidpn_2000 shhidpn_2002
	married_1992 married_1994 married_1996 married_1998 married_2000 married_2002
	work_1992 work_1994 work_1996 work_1998 work_2000 work_2002
	yrmarried_1992 yrmarried_1994 yrmarried_1996 yrmarried_1998 yrmarried_2000 yrmarried_2002
	totinc_1992 totinc_1994 totinc_1996 totinc_1998 totinc_2000 totinc_2002
	lninc_1992 lninc_1994 lninc_1996 lninc_1998 lninc_2000 lninc_2002);
	set rand.rndhrs_h(keep = hhidpn %wvlist(S,HHIDPN) %wvlist(R,MSTAT WORK MCURLN) %wvlist(H,ITOT ) );
FORMAT _ALL_ ; /* don't use rand formats*/

** Source of CPI-U: http://data.bls.gov/  
** Not Seasonally Adjusted, U.S. city average, 
** All items, 1982-84=100
** CUUR0000SA0,CUUS0000SA0;
array pindex{1991:2002} _temporary_;
  pindex{1991} = 136.2 ; 
  pindex{1992} = 140.3 ;
  pindex{1993} = 144.5 ; 
  pindex{1994} = 148.2 ;  
  pindex{1995} = 152.4 ;
  pindex{1996} = 156.9 ; 
  pindex{1997} = 160.5 ;  
  pindex{1998} = 163.0 ;
  pindex{1999} = 166.6 ; 
  pindex{2000} = 172.2 ;  
  pindex{2001} = 177.1 ;
  pindex{2002} = 179.9 ; 

%workstat(1,1992); %workstat(2,1994); %workstat(3,1996);
%workstat(4,1998); %workstat(5,2000); %workstat(6,2002);

%marstat(1,1992); %marstat(2,1994); %marstat(3,1996);
%marstat(4,1998); %marstat(5,2000); %marstat(6,2002);

%wealth(1,1992); %wealth(2,1994); %wealth(3,1996);
%wealth(4,1998); %wealth(5,2000); %wealth(6,2002);
run;

%macro ages(yr);

age_&yr = &yr - birthyr;

age_40_&yr = 0;  age_50_&yr = 0;;
age_60_&yr = 0; 

if  age_&yr < 50 then age_40_&yr = 1;
	else if 50 <= age_&yr < 60 then age_50_&yr = 1;
	else if 60 <= age_&yr then age_60_&yr = 1;

%mend;

data hrs9202_wkr(keep = afinr hhidpn no_sp_prt_1992 no_sp_prt_1994 no_sp_prt_2002 
	ngambles age_1992 age_1994 age_1998 age_2000 age_2002
	age_40_1992 age_50_1992 age_60_1992 
	age_40_1994 age_50_1994 age_60_1994 
	age_40_1998 age_50_1998 age_60_1998 
	age_40_2000 age_50_2000 age_60_2000 
	age_40_2002 age_50_2002 age_60_2002 
	risk_1992 risk_1994 risk_1998 risk_2000 risk_2002
	shhidpn_1992 shhidpn_1994 shhidpn_1996 shhidpn_1998 shhidpn_2000 shhidpn_2002 yrmarried_1992 male);
	merge hrs9202(in=inHRS) rand;
	by hhidpn; if inHRS; 

** Must be working at time of gamble response;
if work_1992 = 1 then risk_1992 = jrc4_1992;
if work_1994 = 1 then risk_1994 = jrc6_1994;
if work_1998 = 1 then risk_1998 = jrc6_1998;
if work_2000 = 1 then risk_2000 = jrc6_2000;
if work_2002 = 1 then risk_2002 = jrc6_2002;

** Must respond to gambles in 1992 HRS;
if 1 <= risk_1992 <= 4;

** Age restriction;
if 40 <= (1992 - birthyr) < 70;

%ages(1992); %ages(1994); %ages(1998); %ages(2000); %ages(2002);

ngambles = 0;
	if risk_1992 > 0 then ngambles = ngambles + 1;
	if risk_1994 > 0 then ngambles = ngambles + 1;
	if risk_1998 > 0 then ngambles = ngambles + 1;
	if risk_2000 > 0 then ngambles = ngambles + 1;
	if risk_2002 > 0 then ngambles = ngambles + 1;

if risk_1992 < 0 then risk_1992 = 0;
if risk_1994 < 0 then risk_1994 = 0;
if risk_1998 < 0 then risk_1998 = 0;
if risk_2000 < 0 then risk_2000 = 0;
if risk_2002 < 0 then risk_2002 = 0;

proc freq data = hrs9202_wkr;
tables ngambles age_40_1992 age_50_1992 age_60_1992; 

** Set up spouses;
data hrs_spouses(keep = hhidpn age_1992 age_1994 age_1998 age_2000 age_2002
	risk_1992 risk_1994 risk_1998 risk_2000 risk_2002 no_sp_prt_1992 no_sp_prt_1994 no_sp_prt_2002);
	set hrs9202_wkr;
proc sort data = hrs_spouses; by hhidpn; run;

** 1992 Spouse;
proc sort data = hrs9202_wkr; by shhidpn_1992;

data hrs9202_wkr;
	merge hrs9202_wkr(in=inG) hrs_spouses(keep = hhidpn age_1992 age_1994 age_1998 age_2000 age_2002
	risk_1992 risk_1994 risk_1998 risk_2000 risk_2002 no_sp_prt_1992 no_sp_prt_1994 no_sp_prt_2002
	rename=(hhidpn=shhidpn_1992 risk_1992=risk_S_1992 age_1992=age_S_1992 risk_1994=risk_S_1994 age_1994=age_S_1994
	risk_1998=risk_S_1998 age_1998=age_S_1998 risk_2000=risk_S_2000 age_2000=age_S_2000 risk_2002=risk_S_2002 age_2002=age_S_2002
	no_sp_prt_1992=no_sp_prt_S_1992 no_sp_prt_1994=no_sp_prt_S_1994 no_sp_prt_2002=no_sp_prt_S_2002));
	by shhidpn_1992;
	if inG;

if no_sp_prt_1992 = 1 and no_sp_prt_S_1992 = 1 then iwgroup_92 = 1;
	else if no_sp_prt_1992 = 0 and no_sp_prt_S_1992 = 0 then iwgroup_92 = 2;
	else if (no_sp_prt_1992 = 0 and no_sp_prt_S_1992 = 1) 
		or (no_sp_prt_1992 = 1 and no_sp_prt_S_1992 = 0) then iwgroup_92 = 3;
	else iwgroup_92 = 9;

if no_sp_prt_1994 = 1 and no_sp_prt_S_1994 = 1 then iwgroup_94 = 1;
	else if no_sp_prt_1994 = 0 and no_sp_prt_S_1994 = 0 then iwgroup_94 = 2;
	else if (no_sp_prt_1994 = 0 and no_sp_prt_S_1994 = 1) 
		or (no_sp_prt_1994 = 1 and no_sp_prt_S_1994 = 0) then iwgroup_94 = 3;
	else iwgroup_94 = 9;

if iwgroup_92 = 1 then togeth_92 = 0;
else if iwgroup_92 in(2,3) then togeth_92 = 1;
else togeth_92 = 9;

if iwgroup_94 = 1 then togeth_94 = 0;
else if iwgroup_94 in(2,3) then togeth_94 = 1;
else togeth_94 = 9;

** Set up pairs;
data hrs_self(keep=c cR age age_R year yearR age_diff);
	set hrs9202_wkr;

if risk_1992 > 0 and risk_1994 > 0 then do;
	c = risk_1992;
	cR = risk_1994;
	age = age_1992;
	age_R = age_1994;
	year = 1992;
	yearR = 1994;
	age_diff = age_1994 - age_1992;
 output;
 end;

if risk_1992 > 0 and risk_1998 > 0 then do;
	c = risk_1992;
	cR = risk_1998;
	age = age_1992;
	age_R = age_1998;
	year = 1992;
	yearR = 1998;
	age_diff = age_1998 - age_1992;
 output;
 end;

 if risk_1992 > 0 and risk_2000 > 0 then do;
 	c = risk_1992;
	cR = risk_2000;
	age = age_1992;
	age_R = age_2000;
	year = 1992;
	yearR = 2000;
	age_diff = age_2000 - age_1992;
 output;
 end;

 if risk_1992 > 0 and risk_2002 > 0 then do;
	age_diff = age_2002 - age_1992;
	c = risk_1992;
	cR = risk_2002;
	age = age_1992;
	age_R = age_2002;
	year = 1992;
	yearR = 2002;
 output;
 end;

if risk_1994 > 0 and risk_1998 > 0 then do;
	age_diff = age_1998 - age_1994;
	c = risk_1994;
	cR = risk_1998;
	age = age_1994;
	age_R = age_1998;
	year = 1994;
	yearR = 1998;
 output;
 end;

 if risk_1994 > 0 and risk_2000 > 0 then do;
	age_diff = age_2000 - age_1994;
	c = risk_1994;
	cR = risk_2000;
	age = age_1994;
	age_R = age_2000;
	year = 1994;
	yearR = 2000;
 output;
 end;

 if risk_1994 > 0 and risk_2002 > 0 then do;
	age_diff = age_2002 - age_1994;
	c = risk_1994;
	cR = risk_2002;
	age = age_1994;
	age_R = age_2002;
	year = 1994;
	yearR = 2002;
 output;
 end;

 if risk_1998 > 0 and risk_2000 > 0 then do;
	age_diff = age_2000 - age_1998;
	c = risk_1998;
	cR = risk_2000;
	age = age_1998;
	age_R = age_2000;
	year = 1998;
	yearR = 2000;
 output;
 end;

 if risk_1998 > 0 and risk_2002 > 0 then do;
	age_diff = age_2002 - age_1998;
	c = risk_1998;
	cR = risk_2002;
	age = age_1998;
	age_R = age_2002;
	year = 1998;
	yearR = 2002;
 output;
 end;

 if risk_2000 > 0 and risk_2002 > 0 then do;
	age_diff = age_2002 - age_2000;
	c = risk_2000;
	cR = risk_2002;
	age = age_2000;
	age_R = age_2002;
	year = 2000;
	yearR = 2002;
 output;
 end;

proc corr spearman data = hrs_self;
var c cR; run;

proc means; var age_diff age age_R; run;
proc freq; table year*yearR; run;

data hrs_spouse(keep=c cR age age_R year yearR age_diff togeth_92 togeth_94 yrmarried_1992);
	set hrs9202_wkr;

if yrmarried_1992 = . then yrmarried_1992 = 0;

** c = husband, cR = wife;
if risk_1992 > 0 and risk_S_1992 > 0 and male = 1 then do;
	c = risk_1992;
	cR = risk_S_1992;
	age = age_1992;
	age_R = age_S_1992;
	year = 1992;
	yearR = 1992;
	age_diff = age_1992 - age_S_1992;
 output;
 end;

proc means;

proc corr spearman data = hrs_spouse;
var c cR; where togeth_92 = 0; run;

data hrs_spouse;
	set hrs_spouse;

abs_age_diff = abs(age_diff);

run;

proc univariate; var yrmarried_1992; where yrmarried_1992 > 0; 
proc means; var age_diff abs_age_diff age age_R; 

data hrs9202_wkr(keep = hhidpn 
	ngambles age_1992 age_1994 age_1998 age_2000 age_2002
	age_40_1992 age_50_1992 age_60_1992 
	risk_1992 risk_1994 risk_1998 risk_2000 risk_2002);
set hrs9202_wkr; 

run;

** Macro Exports to Excel **;
%macro outts(name);
proc dbload dbms=excel data=&name;
path="G:\res\Research\RiskPrefs\PSID_KSS\Analysis\&name..xls";
putnames yes;
limit=0;
load;
run;
%mend outts; 
%outts(hrs9202_wkr);
%outts(hrs_self);
%outts(hrs_spouse); run;
run;

