function [Elntheta,Etheta, Egamma] = Impute_KSS(mux,sqb,sigmau,sigma,c);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Impute_KSS.m
% Computes the E(theta|c,X), E(gamma|c,X)
% Claudia R. Sahm (claudia.r.sahm@frb.gov)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global model  

maxit = 200;
tol = 1.0e-6; 

%% Compute Risk Tolerance Cutoffs for Risk Categories;
dfrac = 1 - [1/10,1/5,1/3,1/2,3/4]; %(1 - downside risk) 
cutoff = zeros(1,size(dfrac,2));
for j = 1:size(dfrac,2)
    gamma = 5; % Initial guess for coefficient of relative risk aversion;
    for it=1:maxit  % Newton Rootfinder;  
        [fval,fjac] = dutility(gamma,dfrac(1,j));
        gamma = gamma - fjac\fval; 
        if norm(fval) < tol, break, end 
    end
    cutoff(1,j) = gamma.^-1; % Risk tolerance (Inverse of Risk Aversion);
end

N = size(c,1);

%% Assign cutoff ranges
cpt6 = [-1.0e+77;log(cutoff)';1.0e+77]; % 6 categories

% Likelihood of individual being in risk categories
mu = mux + sqb; % mean of signal

%% CE of Risk Tolerance

i = find(c > 0); 
	Eu(i,1) = sigmau^2/sigma*(norm_pdf((cpt6(c(i))-mu)/sigma) - norm_pdf((cpt6(c(i)+1)-mu)/sigma) ) ./ ...
        (norm_cdf((cpt6(c(i)+1)-mu)/sigma)-norm_cdf((cpt6(c(i))-mu)/sigma));

Elntheta = mux + Eu;

%% CE of Risk Tolerance

num = ones(N,1);
den = ones(N,1);

i = find(c>0); 
   num(i,1) = norm_cdf((cpt6(c(i)+1) - mu - sigmau^2)/sigma) - ...
       norm_cdf((cpt6(c(i)) - mu - sigmau^2)/sigma);
   den(i,1) = norm_cdf((cpt6(c(i)+1) - mu)/sigma) - norm_cdf((cpt6(c(i)) - mu)/sigma);

Etheta = exp(mux+sigmau^2/2).*(num./den);

%% CE of Risk Aversion

num = ones(N,1);
den = ones(N,1);

i = find(c>0); 
   num(i,1) = norm_cdf((cpt6(c(i)+1) - mu + sigmau^2)/sigma) - ...
       norm_cdf((cpt6(c(i))-mu + sigmau^2)/sigma);
   den(i,1) = norm_cdf((cpt6(c(i)+1) - mu)/sigma)-norm_cdf((cpt6(c(i))-mu)/sigma);

Egamma = exp(-mux +sigmau^2/2).*(num./den);
