%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PSID_KSS.m
%% Claudia Sahm
%% Updated October 22, 2008;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

dfile = ['PSID_KSS_',DATESTR(clock,1),'.out'];
diary(dfile);

%% PSID Respondent Only File
[id,c,age,age_20,age_30,age_40,age_50,age_60] = ...
textread('psid_rsp.dat','%f %f %f %f %f %f %f %f');
N = size(id,1);
 
% Own characteristics 
X = [age_20,age_30,age_40,age_50,age_60];  

X = sparse(X);
save psiddata_rsp 

%% PSID Respondent-Relative File
clear all;

[id,c,age,type_R,cR,age_R,sibtype_R, age_20,age_30,age_40,age_50,age_60,...
age_R_20,age_R_30,age_R_40,age_R_50,age_R_60] = ...
textread('psid_rlt.dat',' %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f');

N = size(id,1);

% Own characteristics 
X = [ones(N,1)];
% Relative characteristics 
XR = [ones(N,1)];

X = sparse(X);
XR = sparse(XR);

save psiddata_rlt 

%% CH Comparison File
clear all;

[id,c,id_R,cR,match] = ...
textread('compareCH.dat',' %f %f %f %f %f');

N = size(id,1);

% Own characteristics 
X = [ones(N,1)];
% Relative characteristics 
XR = [ones(N,1)];

X = sparse(X);
XR = sparse(XR);

save compare_CH 


%% HRS Worker Comparison File
clear all;

[id,c92,c94,c98,c00,c02,age_1992,age_40_1992,age_50_1992,age_60_1992,...
 age_1994,age_1998,age_2000,age_2002,ngambles] = ...
textread('hrs9202_wkr.dat','%f %f %f %f %f %f %f %f %f %f %f %f %f %f %f');

N = size(id,1);

% Own characteristics in 1992 
X92 = [ones(N,1), ones(N,1)];  
% Own characteristics in 1994    
X94 = [ones(N,1), ones(N,1)]; 
% Own characteristics in 1998 
X98 = [ones(N,1), zeros(N,1)];  
% Own characteristics in 2000    
X00 = [ones(N,1), zeros(N,1)]; 
% Own characteristics in 2002    
X02 = [ones(N,1), zeros(N,1)];

X92 = sparse(X92); X94 = sparse(X94);
X98 = sparse(X98); X00 = sparse(X00); X02 = sparse(X02);

save hrs9202

%% HRS Spouse Panel 
clear all;
[yrmarried, togeth_92 togeth_94, c,cR,age,age_R,year,yearR,age_diff,abs_age_diff] = ...
textread('hrs_spouse.dat','%f %f %f %f %f %f %f %f %f %f %f');
N = size(c,1);

% Own characteristics 
X = [ones(N,1)];
% Own later characteristics 
XR = [ones(N,1)];

X = sparse(X);
XR = sparse(XR);

save hrs_spouse


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
global model 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% MODEL 1: Age-Adjusted, No Family Effect, Homoskedastic Error;
clear all;
global model 
model = 1;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'.out'];
diary(dfile);
disp('Age-Adjusted, No Family Effect, Homoskedastic Error')
load psiddata_rsp c* X* N
EstimateRisk_PSID(c,0,ones(N,1),0);
clear 
diary off;

%% MODEL 2: Age-Adjusted, No Family Effect, Heteroskedastic Error;
clear all;
global model 
model = 2;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'.out'];
diary(dfile);
disp('Age-Adjusted, No Family Effect, Heteroskedastic Error')
load psiddata_rsp c* X* 
EstimateRisk_PSID(c,0,X,0);
clear 
diary off;

%%%%%%%%%%%%%%

%% Family Effects

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_Fathers.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Fathers')
load psiddata_rlt c* X* type*
i = find(type_R == 1);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Age-Adjusted Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_Mothers.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Mothers')
load psiddata_rlt c* X* type*
i = find(type_R == 2);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Age-Adjusted Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_Parents.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Parents')
load psiddata_rlt c* X* type* age*
i = find(type_R < 3);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Age-Adjusted Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_Sibs.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Siblings')
load psiddata_rlt c* X* type*
i = find(type_R == 3);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Age-Adjusted Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_SibsFull.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Siblings Full')
load psiddata_rlt c* X* type* sib*
i = find(type_R == 3 & sibtype_R == 1);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Age-Adjusted Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_SibsHalf.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Siblings Half')
load psiddata_rlt c* X* type* sib*
i = find(type_R == 3 & (sibtype_R == 2 | sibtype_R == 3));
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%HRS Models

%% MODEL 1: % Common Mean, Common Variance
clear all;
global model 
model = 1;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS.out'];
diary(dfile);
disp('Common Mean, Common Variance')
load hrs9202 c* X* 
EstimateRisk_HRS(c92,0,0,0,0,X92(:,1),0,0,0,0);
clear 
diary off;

%% MODEL 2: % Age-Adjusted Mean, Common Variance
clear all;
global model 
model = 2;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS.out'];
diary(dfile);
disp('Age-Adjusted Mean, Common Variance - HRS')
load hrs9202 c* X* age*
X = [age_40_1992,age_50_1992,age_60_1992];
EstimateRisk_HRS(c92,0,0,0,0,X,0,0,0,0);
clear 
diary off;


%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS.out'];
diary(dfile);
disp('Common Mean, Common Variance')
load hrs9202 c* X* 
EstimateRisk_HRS(c92,c94,c98,c00,c02,X92(:,1),X94(:,1),X98(:,1),X00(:,1),X02(:,1));
clear 
diary off;

%% MODEL 11: % Common Mean, Common Variance
clear all;
global model 
model = 11;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS.out'];
diary(dfile);
disp('Common Mean, Common Variance - SQB')
load hrs9202 c* X* 
EstimateRisk_HRS(c92,c94,c98,c00,c02,X92(:,1:2),X94(:,1:2),X98(:,1:2),X00(:,1:2),X02(:,1:2));
clear 
diary off;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%HRS Pairs Models

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Self.out'];
diary(dfile);
disp('HRS Data Pairs - Self')
load hrs_self c* X* year*
EstimateRisk_HRS_Pair(c,cR,X,XR,year,yearR);
clear 
diary off;

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year*
EstimateRisk_HRS_Pair(c,cR,X,XR,year,yearR);
clear 
diary off;

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 0);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 0 & togeth_94 == 1);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 0 & togeth_94 == 0);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;


%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_SpouseYrs5.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* yr* togeth*
i = find(yrmarried <= 10 & yrmarried > 0 & togeth_92 == 0);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;




%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 1);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;

%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 1 & togeth_94 == 0);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;


%% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year* togeth*
i = find(togeth_92 == 1 & togeth_94 == 1);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i,:),yearR(i,:));
clear 
diary off;


% MODEL 10: % Common Mean, Common Variance
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year*
i = find(year ~= yearR);
EstimateRisk_HRS_Pair(c(i),cR(i),X(i,:),XR(i,:),year(i),yearR(i));
clear 
diary off;

%% MODEL 13: % Common Mean, Common Variance
clear all;
global model 
model = 13;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Self.out'];
diary(dfile);
disp('HRS Data Pairs - Self')
load hrs_self c* X* year*
X = [X(:,1), X(:,3)];
XR = [XR(:,1), XR(:,3)];
EstimateRisk_HRS_Pair(c,cR,X,XR,year,yearR);
clear 
diary off;



%% MODEL 12: % Common Mean, Common Variance
clear all;
global model 
model = 12;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Self.out'];
diary(dfile);
disp('HRS Data Pairs - Self')
load hrs_self c* X* year*
X = [X(:,1), X(:,3)];
XR = [XR(:,1), XR(:,3)];
EstimateRisk_HRS_Pair(c,cR,X,XR,year,yearR);
clear 
diary off;

%% MODEL 12: % Common Mean, Common Variance
clear all;
global model 
model = 12;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_HRS_Spouse.out'];
diary(dfile);
disp('HRS Data Pairs - Spouse')
load hrs_spouse c* X* year*
X = [X(:,1), X(:,3)];
XR = [XR(:,1), XR(:,3)];
EstimateRisk_HRS_Pair(c,cR,X,XR,year,yearR);
clear 
diary off;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Charles and Hurst Comparisons

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_Overlap.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - Overlap')
load compare_CH c* X* match
i = find(match == 1);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_KSSOnly.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - KSS Only')
load compare_CH c* X* match
i = find(match == 2);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_CHOnly.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - CH Only')
load compare_CH c* X* match
i = find(match == 3);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_CH.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - CH')
load compare_CH c* X* match
i = find(match == 3 | match == 1);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%% MODEL 10: Separate Mean and Variance, Family Effect;
clear all;
global model 
model = 10;
itertime = clock;
disp(DATESTR(itertime,0));
dfile = ['Model_',int2str(model),'_',DATESTR(clock,1),'_KSS.out'];
diary(dfile);
disp('Separate Mean and Variance, Family Effect - KSS')
load compare_CH c* X* match
i = find(match == 2 | match == 1);
EstimateRisk_PSID(c(i),cR(i),X(i,:),XR(i,:));
clear 
diary off;

%%%%%%%%%%%%%%%%%%%%%%%%%

%% All Respondents
[Elntheta,Etheta, Egamma] = Impute_KSS(-1.053,-.208,0.874,1.569,[(1:6)'])

load psiddata_rsp 

Etheta_i = Etheta(c);
disp('Variance of Imputations')
Vproxy = Var(Etheta_i);

disp('Variance of Risk Tolerance')
Var(Etheta_i)
%% Variance Risk Tolerance;
mux = -1.053; sigmax = 0.874;
Vtheta = exp(2*mux+sigmax^2)*(exp(sigmax^2)-1);

disp(sprintf(' Var E(RT|c) = %1.2f Var RT = %1.3f Ratio True-to-Proxy Variance = %1.3f', ...
	Vproxy, Vtheta, Vtheta/Vproxy )); 

%% Age 30-39
[Elntheta,Etheta, Egamma] = Impute_KSS(-1.15,-.208,0.874,1.54,[(1:6)'])

%% Age 50-59
[Elntheta,Etheta, Egamma] = Impute_KSS(-1.80,-.208,0.874,1.80,[(1:6)'])

diary off;
