**************************************
** Data Setup for PSID_KSS           **
** Updated: November 5, 2008         ** 
**************************************;

libname dataout 'G:\res\Data\PSID';
libname final 'G:\res\Research\RiskPrefs\PSID_KSS\Analysis';  

proc sort data = dataout.riskPSID; by id;
proc sort data = dataout.familyPSID; by id;

data gambles;
	merge dataout.riskPSID(in=inRisk) dataout.familyPSID;
by id;
if inRisk;

** Age restriction;
if age >= 20 and age < 70; 

** Individual weight;
wt = ER33318;

** 1996 family identifier;
id96 = ER33301;

** 1968 Family identifier;
id_fam = ER30001;

** PSID family sample;
** 1 = 1968 SRC (representative) sample, 2 = 1997/1999 Immigrant sample; 
** 3 = 1968 Census (poverty) sample, 4 = 1990/1992 Latino sample;
if 1 <= ER30001 <= 2930 then PSIDsample = 1;
	else if 3001 <= ER30001 <= 3511 then PSIDsample = 2;
	else if 5001 <= ER30001 <= 6872 then PSIDsample = 3;
	else if 7001 <= ER30001 <= 9308 then PSIDsample = 4;

** 1968 member type: 1=original sample, 2=child of original sample member, 3 = other sample member;
if 1 <= ER30002 <= 20 then mem68 = 1;
	else if 21 <= ER30002 <= 169 then mem68 = 2;
	else mem68 = 3;

** Gamble respondent's age at time of 1996 interview;
if 0 < ER33304 < 150 then age = ER33304;

** Gamble respondent's gender;
if ER32000 = 1 then male = 1;
else if  ER32000 = 2 then male = 0;

** Family income in 1995;
faminc95 = ER9244;
if faminc95 > 0 then lninc = log(faminc95);
	else lninc = 0;

** Marital status in 1996;
if ER32049 = 1 then married = 1;
	else married = 0;

** Kids in family;
if ER7009 > 0 then kids = 1;
	else kids = 0;

** Gamble respondent's education;
if 0 <= ER33315 < 12 then educat = 1;
 	else if ER33315 = 12 then educat = 2;
	else if 12 < ER33315 < 16 then educat = 3;
	else if ER33315 = 16 then educat = 4;
	else if ER33315 = 17 then educat = 5;

dropout = 0; smcoll = 0; cograd = 0; pscoll = 0;  
if educat = 1 then dropout = 1;
	else if educat = 3 then smcoll = 1;
	else if educat = 4 then cograd = 1;
	else if educat = 5 then pscoll = 1;

** Respondent's race;
if (head = 1 and ER9060 = 2) or (wife = 1 and ER8999 = 2) then black = 1;
	else black = 0;

** Owns a home;
if ER7031 = 1 then homeowner = 1;
	else homeowner = 0;

** Mortgage payment;
if ER7035 = 1 then mortgage = 1;
	else mortgage = 0;

** Keep only gamble respondents;
if 1 <= risk <=6;

proc freq; tables risk; run;
proc freq; tables risk; weight wt; run;

data relative(keep = id wt risk male lninc educat dropout smcoll cograd pscoll 
		age black married mortgage homeowner id96 );
	set gambles;
proc sort data = relative; by id;

** Father's Gambles;
proc sort data = gambles; by id_F;
data gambles;
	merge gambles(in=inG) relative(rename=(id=id_F wt=wt_F risk=risk_F age=age_F 
		male=male_F lninc=lninc_F black=black_F educat=educat_F 
		dropout=dropout_F smcoll=smcoll_F cograd=cograd_F pscoll=pscoll_F
		married=married_F homeowner=homeowner_F mortgage=mortgage_F id96=id96_F ));
	by id_F;
	if inG;

** Mother's Gambles;
proc sort data = gambles; by id_M;
data gambles;
	merge gambles(in=inG) relative(rename=(id=id_M wt=wt_M risk=risk_M age=age_M 
		male=male_M lninc=lninc_M educat=educat_M black=black_M 
		dropout=dropout_M smcoll=smcoll_M cograd=cograd_M pscoll=pscoll_M
		married=married_M homeowner=homeowner_M mortgage=mortgage_M id96=id96_M ));
	by id_M;
	if inG;

** Siblings' Gambles;
%macro sibs(snum);
proc sort data = gambles; by id_S&snum;
data gambles;
	merge gambles(in=inG) relative(rename=(id=id_S&snum wt=wt_S&snum risk=risk_S&snum 
		age=age_S&snum male=male_S&snum lninc=lninc_S&snum educat=educat_S&snum black=black_S&snum 
		dropout=dropout_S&snum smcoll=smcoll_S&snum cograd=cograd_S&snum pscoll=pscoll_S&snum
		married=married_S&snum homeowner=homeowner_S&snum mortgage=mortgage_S&snum id96=id96_S&snum));
	by id_S&snum;
	if inG;

%mend;

%sibs(01); %sibs(02); %sibs(03); %sibs(04); 
%sibs(05); %sibs(06); %sibs(07); %sibs(08); %sibs(09);
%sibs(10); %sibs(11); %sibs(12); %sibs(13); %sibs(14);
%sibs(15); %sibs(16); %sibs(17); 

data gambles_rsp(keep = id wt risk age black married dropout smcoll cograd pscoll male lninc mortgage homeowner);
	set gambles;

proc means;

%macro sibs_R(snum);

** Older Siblings;
if risk_S&snum > 0 and age_S&snum > age then do;
	type_R = 3;
	id_R = id_S&snum;
	wt_R = wt_S&snum;
	risk_R = risk_S&snum;
	age_R = age_S&snum;
	black_R = black_S&snum;
    dropout_R = dropout_S&snum;
	smcoll_R = smcoll_S&snum;
 	cograd_R = cograd_S&snum;
	pscoll_R = pscoll_S&snum;
	male_R = male_S&snum;
	lninc_R = lninc_S&snum;
	married_R = married_S&snum;
	homeowner_R = homeowner_S&snum;
	mortgage_R = mortgage_S&snum;
	sibtype_R = TYPE_S&snum; 
 output;
 end;

 ** "Twin" Siblings;
if risk_S&snum > 0 and age_S&snum = age then do;
	id_R = id_S&snum;
	wt_R = wt_S&snum;
	type_R = 4;
	risk_R = risk_S&snum;
	age_R = age_S&snum;
	black_R = black_S&snum;
    dropout_R = dropout_S&snum;
	smcoll_R = smcoll_S&snum;
 	cograd_R = cograd_S&snum;
	pscoll_R = pscoll_S&snum;
	male_R = male_S&snum;
	lninc_R = lninc_S&snum;
	married_R = married_S&snum;
	homeowner_R = homeowner_S&snum;
	mortgage_R = mortgage_S&snum;
	sibtype_R = TYPE_S&snum; 
 output;
 end;

%mend;

data gambles_rlt(keep = id id_fam type_F type_M wt risk age black married dropout smcoll cograd pscoll male lninc mortgage homeowner
id_R wt_R risk_R age_R black_R married_R dropout_R smcoll_R cograd_R pscoll_R male_R lninc_R mortgage_R homeowner_R
type_R id96 id96_R sibtype_R);
	set gambles;

** Type R: 1=Father, 2=Mother, 3=Older Sibling, 4=Same Age Sibling;

if risk_F > 0 then do;
	id_R = id_F;
	id96_R = id96_F;
	wt_R = wt_F;
	type_R = 1;
	risk_R = risk_F;
	age_R = age_F;
	black_R = black_F;
    dropout_R = dropout_F;
	smcoll_R = smcoll_F;
 	cograd_R = cograd_F;
	pscoll_R = pscoll_F;
	male_R = male_F;
	lninc_R = lninc_F;
	married_R = married_F;
	homeowner_R = homeowner_F;
	mortgage_R = mortgage_F;
	sibtype_R = 0;
 output;
 end;

if risk_M > 0 then do;
	id_R = id_M;
	id96_R = id96_M;
	wt_R = wt_M;
	type_R = 2;
	risk_R = risk_M;
	age_R = age_M;
	black_R = black_M;
    dropout_R = dropout_M;
	smcoll_R = smcoll_M;
 	cograd_R = cograd_M;
	pscoll_R = pscoll_M;
	male_R = male_M;
	lninc_R = lninc_M;
	married_R = married_M;
	homeowner_R = homeowner_M;
	mortgage_R = mortgage_M;
	sibtype_R = 0;
 output;
 end;

%sibs_R(01); %sibs_R(02); %sibs_R(03); %sibs_R(04); 
%sibs_R(05); %sibs_R(06); %sibs_R(07); %sibs_R(08); %sibs_R(09);
%sibs_R(10); %sibs_R(11); %sibs_R(12); %sibs_R(13); %sibs_R(14);
%sibs_R(15); %sibs_R(16); %sibs_R(17); 

proc freq data = gambles_rlt; tables type_R sibtype_R; 

** Keep only one "twin" pair;
proc sort nodupkey data = gambles_rlt out = twin; by id_fam age age_R; where type_R = 4; run;
proc sort data = twin; by id;
proc sort data = gambles_rlt; by id;

data gambles_rlt(drop=id_fam type_F type_M);
	merge gambles_rlt twin(in=inTW keep=id); by id;
if inTW or type_R ne 4;

** Code twins to siblings;
if type_R = 4 then type_R = 3; 
run;

** Father - Son;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 1 and male = 1; run;
** Father - Daughter;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 1 and male = 0; run;
** Mother - Son;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 2 and male = 1; run;
** Mother - Daughter;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 2 and male = 0; run;

data gambles_rlt;
	set gambles_rlt;

** Difference in ages in pair;
age_diff = age_R - age;

** Data set for Charles-Hurst comparison;
data final.gambles_p;
	set final.gambles_rlt;
if type_R in(1,2);

** Replication of Charles and Hurst Table 6;
data repCH;
	set gambles_rlt;
	if type_R in (1,2);

risk_C1 = 0; risk_C2 = 0; risk_C3 = 0; risk_C4 = 0;
risk_P1 = 0; risk_P2 = 0; risk_P3 = 0; risk_P4 = 0;

if risk in(1,2) then risk_C1 = 1;
	else if risk = 3 then risk_C2 = 1;
	else if risk = 4 then risk_C3 = 1;
	else if risk in(5,6) then risk_C4 = 1;

if risk_R in(1,2) then risk_P1 = 1;
	else if risk_R = 3 then risk_P2 = 1;
	else if risk_R = 4 then risk_P3 = 1;
	else if risk_R in(5,6) then risk_P4 = 1;

proc means; var risk_C1-risk_C4 risk_P1-risk_P4;  

 proc reg data=repCH; 
      model risk_C1=risk_P2 risk_P3 risk_P4;   
 proc reg data=repCH; 
      model risk_C2=risk_P2 risk_P3 risk_P4; 
 proc reg data=repCH; 
      model risk_C3=risk_P2 risk_P3 risk_P4;
proc reg data=repCH; 
      model risk_C4=risk_P2 risk_P3 risk_P4;  run;

proc freq; tables risk_P1-risk_P4 risk_C1-risk_C4;


*** Unweighted;
proc means data = gambles_rsp; var age mortgage homeowner male black 
	dropout smcoll cograd pscoll married lninc;   

proc means data = gambles_rlt; var age_R mortgage_R homeowner_R male_R black_R 
	dropout_R smcoll_R cograd_R pscoll_R married_R lninc_R; where type_R in(1,2); 

proc means data = gambles_rlt; var age_R mortgage_R homeowner_R male_R black_R 
	dropout_R smcoll_R cograd_R pscoll_R married_R lninc_R; where type_R = 3; run;

*** Weighted;
proc means data = gambles_rsp vardef = wgt; var age mortgage homeowner male black 
	dropout smcoll cograd pscoll married lninc; weight wt; 

proc means data = gambles_rlt vardef = wgt; var age_R mortgage_R homeowner_R male_R black_R 
	dropout_R smcoll_R cograd_R pscoll_R married_R lninc_R; where type_R in(1,2); weight wt_R; 

proc means data = gambles_rlt vardef = wgt; var age_R mortgage_R homeowner_R male_R black_R 
	dropout_R smcoll_R cograd_R pscoll_R married_R lninc_R; where type_R = 3; weight wt_R; 

data gambles_rsp(keep = id risk age age_20 age_30 age_40 age_50 age_60 wt);
	set gambles_rsp;

age_20 = 0;
age_30 = 0;
age_40 = 0;
age_50 = 0;
age_60 = 0;

if age < 30 then age_20 = 1;
	else if 30 <= age < 40 then age_30 = 1;
	else if 40 <= age < 50 then age_40 = 1;
	else if 50 <= age < 60 then age_50 = 1;
	else if 60 <= age then age_60 = 1;

proc means data = gambles_rsp; var risk age_20 age_30 age_40 age_50 age_60; run;
proc freq data = gambles_rsp; tables age_20 age_30 age_40 age_50 age_60; run;

proc freq data = gambles_rsp; weight wt; tables risk*age_20; run;
proc freq data = gambles_rsp; weight wt; tables risk*age_30; run;
proc freq data = gambles_rsp; weight wt; tables risk*age_40; run;
proc freq data = gambles_rsp; weight wt; tables risk*age_50; run;
proc freq data = gambles_rsp; weight wt; tables risk*age_60; run;

data gambles_rsp(drop = wt);
	set gambles_rsp;

data gambles_rlt(keep = id age age_R type_R risk risk_R age_20 age_30 age_40 age_50 age_60 
	age_R_20 age_R_30 age_R_40 age_R_50 age_R_60 sibtype_R);
	set gambles_rlt;

age_20 = 0;
age_30 = 0;
age_40 = 0;
age_50 = 0;
age_60 = 0;

if age < 30 then age_20 = 1;
	else if 30 <= age < 40 then age_30 = 1;
	else if 40 <= age < 50 then age_40 = 1;
	else if 50 <= age < 60 then age_50 = 1;
	else if 60 <= age then age_60 = 1;

age_R_20 = 0;
age_R_30 = 0;
age_R_40 = 0;
age_R_50 = 0;
age_R_60 = 0;

if age_R < 30 then age_R_20 = 1;
	else if 30 <= age_R < 40 then age_R_30 = 1;
	else if 40 <= age_R < 50 then age_R_40 = 1;
	else if 50 <= age_R < 60 then age_R_50 = 1;
	else if 60 <= age_R then age_R_60 = 1;

proc means data = gambles_rlt; var risk risk_R age_20 age_30 age_40 age_50 age_60 
age_R_20 age_R_30 age_R_40 age_R_50 age_R_60; run;

proc sort data = gambles_rlt; by type_R;
proc means data = gambles_rlt; var risk risk_R age_20 age_30 age_40 age_50 age_60 
age_R_20 age_R_30 age_R_40 age_R_50 age_R_60; by type_R; 

** Parent-Child Transition;
proc freq data=gambles_rlt;
	tables risk_R*risk; where type_R in(1,2);

proc corr spearman data = gambles_rlt;
var risk_R risk;  where type_R in(1,2); run;

** Father-Child Transition;
proc freq data=gambles_rlt;
	tables risk_R*risk; where type_R = 1; 

proc corr spearman data = gambles_rlt;
var risk_R risk;  where type_R = 1; run;

** Mother-Child Transition;
proc freq data=gambles_rlt;
	tables risk_R*risk; where type_R = 2;

proc corr spearman data = gambles_rlt;
var risk_R risk;  where type_R = 2; run;

** Older Sib-Younger Sib Transition;
proc freq data=gambles_rlt;
	tables risk_R*risk; where type_R = 3; run;

proc corr spearman data = gambles_rlt;
var risk_R risk;  where type_R = 3; run;

** Full Siblings;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 3 and sibtype_R = 1; run;

** Half Siblings;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 3 and sibtype_R in(2,3); run;

** At least Half Siblings;
proc corr spearman data = gambles_rlt;
var risk risk_R;  where type_R = 3 and sibtype_R > 3; run;

** Macro Exports to Excel **;
%macro outts(name);
proc dbload dbms=excel data=&name;
path="G:\res\Research\RiskPrefs\PSID_KSS\Analysis\&name..xls";
putnames yes;
limit=0;
load;
run;
%mend outts; 
%outts(gambles_rsp);
%outts(gambles_rlt);
run;

** PSID Imputations for Gamble Respondents, Age 20-69;

data final.psidimpute(drop=risk);
	set dataout.riskPSID(keep=ER30001 ER30002 ER33301 risk);

rc = risk;

if 1 <= rc <=6;

if rc = 1 then log_rtol = -1.602;
	else if rc = 2 then log_rtol = -1.179;
	else if rc = 3 then log_rtol = -0.976;
	else if rc = 4 then log_rtol = -0.774;
	else if rc = 5 then log_rtol = -0.504;
	else if rc = 6 then log_rtol = -0.085;

if rc = 1 then rtol = 0.270;
	else if rc = 2 then rtol = 0.401;
	else if rc = 3 then rtol = 0.491;
	else if rc = 4 then rtol = 0.601;
	else if rc = 5 then rtol = 0.790;
	else if rc = 6 then rtol = 1.218;

if rc = 1 then ravers = 6.70;
	else if rc = 2 then ravers = 4.24;
	else if rc = 3 then ravers = 3.46;
	else if rc = 4 then ravers = 2.83;
	else if rc = 5 then ravers = 2.17;
	else if rc = 6 then ravers = 1.44;
run;

proc means data = final.psidimpute; run;
