function Li = like(b,c,cR,X,XR);

%% Value of likelihood for gamble respondents
%% Gaussian quadrature
%% Fjdac.m computes numerical gradient
%% Updated October 22, 2008;
%% Claudia Sahm

global cpt6 model  

N = size(X,1);
K = size(X,2);
B = size(b,1);

%% Starting point of unobserved effect
A = K + 1;

% Mean of own risk tolerance 
if model < 10
	muX = X*b(1:K,1);   
    
elseif model == 10
	muX = X*b(1,1);
	muXR = XR*b(2,1);
end

if model == 1 
    sigmae = repmat(b(A,1),N,1); 
	
elseif model == 2
    sigmaex = b(A:A+K-1,1); 
    sigmae = (X*sigmaex);

elseif model == 10
	A = 3;
	sigmau = b(A,1);
	sigmaex = b(A+1,1); 
	sigmaexR = b(A+2,1); 
	sigmae = X*sigmaex;
	sigmaeR = XR*sigmaexR;  
end    

%%%% Single Response %%%%
if model < 10
LiO = ones(N,1);

% Own gamble response
i = find(c >= 1 & c <= 6); 
LiO(i,1) = norm_cdf((cpt6(c(i)+1)-muX(i))./sigmae(i)) - ...
        norm_cdf((cpt6(c(i))-muX(i))./sigmae(i));

%% Log-likelihood of own risk category
Li = log(LiO);

%%%% Family Pairs %%%%
elseif model >= 10

Li = ones(N,1);

% Pieces to Likelihood function
Nodes = 20;
LiO = ones(N,Nodes);
LiR = ones(N,Nodes);
 
% Guassian quadrature for random effect
[xL,pL] = qnwnorm(Nodes,0,sigmau^2); 

% Own gamble response
i = find(c >= 1 & c <= 6);
if size(i,1) > 0;
	for j = 1:Nodes;
  		LiO(i,j) = norm_cdf((cpt6(c(i)+1)-muX(i)-xL(j))./sigmae(i)) - ...
        	norm_cdf((cpt6(c(i))-muX(i)-xL(j))./sigmae(i));
end
end

% Relative's gamble response
i = find(cR >= 1 & cR <= 6);
if size(i,1) > 0;
for j = 1:Nodes;
LiR(i,j) = norm_cdf((cpt6(cR(i)+1)-muXR(i)-xL(j))./sigmaeR(i)) - ...
       	norm_cdf((cpt6(cR(i))-muXR(i)-xL(j))./sigmaeR(i));
end     
end 

%% Log-likelihood of father-child pair's risk categories
Li = log((LiO.*LiR)*pL);

end



