function Li = like_HRS(b,c92,c94,c98,c00,c02,X92,X94,X98,X00,X02);

%% Value of likelihood for gamble respondents
%% Gaussian quadrature
%% Fjdac.m computes numerical gradient
%% Updated October 23, 2008;
%% Claudia Sahm

global cpt4 cpt6 model  

N = size(X92,1);
K = size(X92,2);
B = size(b,1);

%% Starting point of unobserved effect
A = K + 1;

% Mean of 1992 risk tolerance 
muX92 = X92*b(1:K,1);   
     
% Mean of relative's risk tolerance 
if model >= 10
	muX94 = X94*b(1:K,1);  
	muX98 = X98*b(1:K,1);   
	muX00 = X00*b(1:K,1);    
	muX02 = X02*b(1:K,1);  
end

if model == 1  
    sigmae92 = repmat(b(A,1),N,1); 
	
elseif model == 2
    sigmaex = b(A:A+K-1,1); 
    sigmae92 = (X92*sigmaex);

elseif model == 10 | model == 11
    sigmau = b(A,1);
    sigmae92 = repmat(b(A+1),N,1); 
    sigmae94 = repmat(b(A+1),N,1); 
    sigmae98 = repmat(b(A+1),N,1); 
    sigmae00 = repmat(b(A+1),N,1); 
    sigmae02 = repmat(b(A+1),N,1); 

end    

%%%% Single Response %%%%
if model < 10
Li92 = ones(N,1);

% 1992 Gamble Response
i = find(c92 >= 1 & c92 <= 4); 
Li92(i,1) = norm_cdf((cpt4(c92(i)+1)-muX92(i))./sigmae92(i)) - ...
        norm_cdf((cpt4(c92(i))-muX92(i))./sigmae92(i));

%% Log-likelihood of 1992 risk category
Li = log(Li92);

%%%% Family Pairs %%%%
elseif model >= 10

% Guassian quadrature for random effect
Nodes = 20;
[xL,pL] = qnwnorm(Nodes,0,sigmau^2); 

% Pieces to Likelihood function
Li92 = ones(N,Nodes);
Li94 = ones(N,Nodes);
Li98 = ones(N,Nodes);
Li00 = ones(N,Nodes);
Li02 = ones(N,Nodes);

% 1992 gamble response
i = find(c92 >= 1 & c92 <= 4); 
if size(i,1) > 1
for j = 1:Nodes;
    Li92(i,j) = norm_cdf((cpt4(c92(i)+1)-muX92(i)-xL(j))./sigmae92(i)) - ...
        norm_cdf((cpt4(c92(i))-muX92(i)-xL(j))./sigmae92(i));
end
end

% 1994 gamble response
i = find(c94 >= 1 & c94 <= 6);
if size(i,1) > 1 
for j = 1:Nodes;
    Li94(i,j) = norm_cdf((cpt6(c94(i)+1)-muX94(i)-xL(j))./sigmae94(i)) - ...
        norm_cdf((cpt6(c94(i))-muX94(i)-xL(j))./sigmae94(i));
end     
end

% 1998 gamble response
i = find(c98 >= 1 & c98 <= 6); 
if size(i,1) > 1
for j = 1:Nodes;
    Li98(i,j) = norm_cdf((cpt6(c98(i)+1)-muX98(i)-xL(j))./sigmae98(i)) - ...
        norm_cdf((cpt6(c98(i))-muX98(i)-xL(j))./sigmae98(i));
end     
end

% 2000 gamble response
i = find(c00 >= 1 & c00 <= 6); 
if size(i,1) > 1
for j = 1:Nodes;
    Li00(i,j) = norm_cdf((cpt6(c00(i)+1)-muX00(i)-xL(j))./sigmae00(i)) - ...
        norm_cdf((cpt6(c00(i))-muX00(i)-xL(j))./sigmae00(i));
end     
end

% 2002 gamble response
i = find(c02 >= 1 & c02 <= 6); 
if size(i,1) > 1
for j = 1:Nodes;
    Li02(i,j) = norm_cdf((cpt6(c02(i)+1)-muX02(i)-xL(j))./sigmae02(i)) - ...
        norm_cdf((cpt6(c02(i))-muX02(i)-xL(j))./sigmae02(i));
end     
end

%% Log-likelihood of pair's risk categories
Li = log((Li92.*Li94.*Li98.*Li00.*Li02)*pL);

end




